@@ -262,7 +262,7 @@ bool ChartPrivate::loadXmlPlotArea(QXmlStreamReader &reader)
 
 bool ChartPrivate::loadXmlXxxChart(QXmlStreamReader &reader)
 {
-    QStringRef name = reader.name();
+    QStringView name = reader.name();
     if (name == QLatin1String("pieChart")) chartType = Chart::CT_Pie;
     else if (name == QLatin1String("pie3DChart")) chartType = Chart::CT_Pie3D;
     else if (name == QLatin1String("barChart")) chartType = Chart::CT_Bar;
@@ -301,7 +301,7 @@ bool ChartPrivate::loadXmlSer(QXmlStreamReader &reader)
     while (!reader.atEnd() && !(reader.tokenType() == QXmlStreamReader::EndElement
                                 && reader.name() == QLatin1String("ser"))) {
         if (reader.readNextStartElement()) {
-            QStringRef name = reader.name();
+            QStringView name = reader.name();
             if (name == QLatin1String("cat") || name == QLatin1String("xVal")) {
                 while (!reader.atEnd() && !(reader.tokenType() == QXmlStreamReader::EndElement
                                             && reader.name() == name)) {
@@ -583,7 +583,7 @@ bool ChartPrivate::loadXmlAxis(QXmlStreamReader &reader)
         if (reader.tokenType() == QXmlStreamReader::StartElement) {
             if (reader.name() == QLatin1String("axPos")) {
                 QXmlStreamAttributes attrs = reader.attributes();
-                QStringRef pos = attrs.value(QLatin1String("val"));
+                QString pos = attrs.value(QLatin1String("val")).toString();
                 if (pos == QLatin1String("l"))
                     axis->axisPos = XlsxAxis::Left;
                 else if (pos == QLatin1String("r"))
