@@ -13,6 +13,8 @@ DCORE_USE_NAMESPACE
 
 namespace DDLog {
    inline Q_LOGGING_CATEGORY(appLog,"org.deepin.devicemanager");
+   inline Q_LOGGING_CATEGORY(deviceControlLog,"org.deepin.devicecontrol");
+   inline Q_LOGGING_CATEGORY(deviceInfoLog,"org.deepin.deviceinfo");
 }
 
 #endif
