@@ -74,6 +74,7 @@ PageDriverManager::PageDriverManager(DWidget *parent)
     connect(DBusDriverInterface::getInstance(), &DBusDriverInterface::installProgressDetail, this, &PageDriverManager::slotRestoreProgress);//还原
     connect(DBusDriverInterface::getInstance(), &DBusDriverInterface::installFinished, this, &PageDriverManager::slotRestoreFinished);
     connect(DBusDriverInterface::getInstance(), &DBusDriverInterface::backupProgressFinished, this, [=](bool success){
+        qCDebug(appLog) << "PageDriverManager backup progress finished, success:" << success;
         if (success) {
             mp_BackupThread->setStatus(DriverBackupThread::Success);
         } else {
@@ -97,6 +98,7 @@ PageDriverManager::PageDriverManager(DWidget *parent)
     connect(mp_DriverBackupInfoPage, &PageDriverBackupInfo::redetected, this, &PageDriverManager::startScanning);
 
     connect(mp_DriverRestoreInfoPage, &PageDriverRestoreInfo::gotoBackup, this, [=](){
+        qCDebug(appLog) << "PageDriverManager gotoBackup triggered";
         mp_ListView->setCurType(tr("Driver Backup"));
         mp_ListView->itemClicked(tr("Driver Backup"));
     });
@@ -145,11 +147,13 @@ PageDriverManager::~PageDriverManager()
 
 void PageDriverManager::addDriverInfo(DriverInfo *info)
 {
+    qCDebug(appLog) << "PageDriverManager::addDriverInfo, name:" << info->name();
     m_ListDriverInfo.append(info);
 }
 
 bool PageDriverManager::isFirstScan()
 {
+    qCDebug(appLog) << "PageDriverManager::isFirstScan, isFirstScan:" << m_IsFirstScan << "isScanning:" << m_Scanning;
     if (m_IsFirstScan)
         return true;
     if (m_Scanning || networkIsOnline())
@@ -159,27 +163,32 @@ bool PageDriverManager::isFirstScan()
 
 bool PageDriverManager::isInstalling()
 {
+    qCDebug(appLog) << "PageDriverManager::isInstalling, isInstalling:" << (mp_CurDriverInfo != nullptr);
     return mp_CurDriverInfo != nullptr;
 }
 
 bool PageDriverManager::isBackingup()
 {
+    qCDebug(appLog) << "PageDriverManager::isBackingup, isBackingup:" << (mp_CurBackupDriverInfo != nullptr);
     return mp_CurBackupDriverInfo != nullptr;
 
 }
 
 bool PageDriverManager::isRestoring()
 {
+    qCDebug(appLog) << "PageDriverManager::isRestoring, isRestoring:" << (mp_CurRestoreDriverInfo != nullptr);
     return mp_CurRestoreDriverInfo != nullptr;
 }
 
 bool PageDriverManager::isScanning()
 {
+    qCDebug(appLog) << "PageDriverManager::isScanning, isScanning:" << m_Scanning;
     return m_Scanning;
 }
 
 void PageDriverManager::updateListView(const QList<QPair<QString, QString> > &lst)
 {
+    qCDebug(appLog) << "PageDriverManager::updateListView, count:" << lst.size();
     // 更新左边的列表
     if (mp_ListView)
         mp_ListView->updateListItems(lst);
@@ -196,6 +205,7 @@ void PageDriverManager::scanDriverInfo()
     m_Scanning = true;
     // 如果在安装、备份、还原过程中则不扫描
     if (mp_CurDriverInfo || mp_CurBackupDriverInfo || mp_CurRestoreDriverInfo) {
+        qCDebug(appLog) << "Scan skipped - operation already in progress";
         return;
     }
 
@@ -213,6 +223,7 @@ void PageDriverManager::scanDriverInfo()
 
 void PageDriverManager::slotDriverOperationClicked(int index, int itemIndex, DriverOperationItem::Mode mode)
 {
+    qCDebug(appLog) << "PageDriverManager::slotDriverOperationClicked, index:" << index << "itemIndex:" << itemIndex << "mode:" << mode;
     mp_DriverInstallInfoPage->headWidget()->setReDetectEnable(false);
     mp_DriverBackupInfoPage->headWidget()->setReDetectEnable(false);
     mp_DriverRestoreInfoPage->headWidget()->setReDetectEnable(false);
@@ -220,28 +231,35 @@ void PageDriverManager::slotDriverOperationClicked(int index, int itemIndex, Dri
     switch (mode) {
     case DriverOperationItem::INSTALL:
     case DriverOperationItem::UPDATE:
+        qCDebug(appLog) << "PageDriverManager::slotDriverOperationClicked install/update driver";
         // 如果已经在安装过程中，则直接添加到list
         // 如果不在安装过程中则需要安装
         addToDriverIndex(index);
         if (! mp_CurDriverInfo) {
+            qCDebug(appLog) << "Not in installation process, start installing next driver.";
             installNextDriver();
         }
         break;
 
     case DriverOperationItem::BACKUP:
         ///驱动备份
+        qCDebug(appLog) << "PageDriverManager::slotDriverOperationClicked backup driver";
         addToBackupIndex(index);
         if (!mp_CurBackupDriverInfo) {
+            qCDebug(appLog) << "Not in backup process, start backing up next driver.";
             backupNextDriver();
         }
         break;
 
     case DriverOperationItem::RESTORE:
         ///驱动还原
+        qCDebug(appLog) << "PageDriverManager::slotDriverOperationClicked restore driver";
         mp_CurRestoreDriverInfo = m_ListDriverInfo[index];
+        qCDebug(appLog) << "Restoring driver:" << mp_CurRestoreDriverInfo->name() << "from" << mp_CurRestoreDriverInfo->backupFileName();
         DBusDriverInterface::getInstance()->installDriver(mp_CurRestoreDriverInfo->backupFileName());
         //将其它项置灰
         for (int restorableIndex : m_ListRestorableIndex) {
+            qCDebug(appLog) << "Disabling item at index:" << restorableIndex;
             mp_DriverRestoreInfoPage->setItemOperationEnable(restorableIndex, false);
         }
 
@@ -252,6 +270,7 @@ void PageDriverManager::slotDriverOperationClicked(int index, int itemIndex, Dri
 
 void PageDriverManager::slotItemCheckedClicked(int index, bool checked)
 {
+    qCDebug(appLog) << "PageDriverManager::slotItemCheckedClicked, index:" << index << "checked:" << checked;
     if (!checked) {
         // 取消选中则从list中删除
         removeFromDriverIndex(index);
@@ -260,6 +279,7 @@ void PageDriverManager::slotItemCheckedClicked(int index, bool checked)
         // 如果在安装过程中：1. 添加到list  2. 将item置灰
         addToDriverIndex(index);
         if (mp_CurDriverInfo) {
+            qCDebug(appLog) << "Installation in progress, disabling checkbox.";
             mp_DriverInstallInfoPage->setCheckedCBDisnable();
         }
     }
@@ -267,6 +287,7 @@ void PageDriverManager::slotItemCheckedClicked(int index, bool checked)
 
 void PageDriverManager::slotBackupItemCheckedClicked(int index, bool checked)
 {
+    qCDebug(appLog) << "PageDriverManager::slotBackupItemCheckedClicked, index:" << index << "checked:" << checked;
     if (!checked) {
         // 取消选中则从list中删除
         removeFromBackupIndex(index);
@@ -275,6 +296,7 @@ void PageDriverManager::slotBackupItemCheckedClicked(int index, bool checked)
         // 如果在备份过程中：1. 添加到list  2. 将item置灰
         addToBackupIndex(index);
         if (mp_CurBackupDriverInfo) {
+            qCDebug(appLog) << "Backup in progress, disabling checkbox.";
             mp_DriverBackupInfoPage->setCheckedCBDisnable();
         }
     }
@@ -282,8 +304,11 @@ void PageDriverManager::slotBackupItemCheckedClicked(int index, bool checked)
 
 void PageDriverManager::slotDownloadProgressChanged(QStringList msg)
 {
-    if (! mp_CurDriverInfo)
+    qCDebug(appLog) << "PageDriverManager::slotDownloadProgressChanged, msg:" << msg;
+    if (! mp_CurDriverInfo) {
+        qCDebug(appLog) << "No driver info, return.";
         return;
+    }
     // 将下载过程时时更新到表格上方的状态里面 qCInfo(appLog) << "Download ********** " << msg[0] << " , " << msg[1] << " , " << msg[2];
     mp_DriverInstallInfoPage->headWidget()->setDownloadUI(mp_CurDriverInfo->type(), msg[2], msg[1], mp_CurDriverInfo->size(), msg[0].toInt());
     // 设置表格下载中的状态
@@ -291,25 +316,35 @@ void PageDriverManager::slotDownloadProgressChanged(QStringList msg)
 
 void PageDriverManager::slotDownloadFinished()
 {
-    if (! mp_CurDriverInfo)
+    qCDebug(appLog) << "PageDriverManager::slotDownloadFinished";
+    if (! mp_CurDriverInfo) {
+        qCDebug(appLog) << "No driver info, return.";
         return;
+    }
 
     mp_DriverInstallInfoPage->slotDownloadFinished(m_CurIndex, mp_CurDriverInfo->status());
 }
 
 void PageDriverManager::slotInstallProgressChanged(int progress)
 {
-    if (! mp_CurDriverInfo)
+    qCDebug(appLog) << "PageDriverManager::slotInstallProgressChanged, progress:" << progress;
+    if (! mp_CurDriverInfo) {
+        qCDebug(appLog) << "No driver info, return.";
         return;
+    }
     // 当进度小于50时，apt处于下载过程
     if (progress <= 50) {
-        if (progress > 45)
+        if (progress > 45) {
+            qCDebug(appLog) << "Progress > 45, setting status to ST_INSTALL";
             mp_CurDriverInfo->m_Status = ST_INSTALL;
+        }
         QString speed = "";
         QString size = "";
         getDownloadInfo(progress * 2, mp_CurDriverInfo->m_Byte, speed, size);
+        qCDebug(appLog) << "Updating download UI, speed:" << speed << "size:" << size;
         mp_DriverInstallInfoPage->headWidget()->setDownloadUI(mp_CurDriverInfo->type(), speed, size, mp_CurDriverInfo->size(), progress * 2);
     } else {
+        qCDebug(appLog) << "Progress > 50, setting status to ST_INSTALL and updating install UI";
         mp_CurDriverInfo->m_Status = ST_INSTALL;
         // 设置表头状态
         mp_DriverInstallInfoPage->headWidget()->setInstallUI(mp_CurDriverInfo->type(), mp_CurDriverInfo->name(), (progress - 50) * 2);
@@ -321,6 +356,7 @@ void PageDriverManager::slotInstallProgressChanged(int progress)
 
 void PageDriverManager::slotInstallProgressFinished(bool bsuccess, int err)
 {
+    qCDebug(appLog) << "PageDriverManager::slotInstallProgressFinished, success:" << bsuccess << "err:" << err;
     static int successNum = 0;
     static int failedNum = 0;
     if (! mp_CurDriverInfo)
@@ -329,10 +365,13 @@ void PageDriverManager::slotInstallProgressFinished(bool bsuccess, int err)
     // 成功
     if (bsuccess) {
         successNum += 1;
+        qCDebug(appLog) << "Installation successful for" << mp_CurDriverInfo->name() << ", success count:" << successNum;
         m_ListUpdateIndex.removeAt(m_ListUpdateIndex.indexOf(m_CurIndex));
     } else { // 失败
+        qCDebug(appLog) << "Installation failed for" << mp_CurDriverInfo->name() << ", error code:" << err;
         // 通知网络错误
         if (err == EC_NOTIFY_NETWORK) {
+            qCWarning(appLog) << "Network error notified, updating UI.";
             mp_DriverInstallInfoPage->headWidget()->setNetworkErrorUI("0.00MB/s", 0);
             return;
         }
@@ -345,6 +384,7 @@ void PageDriverManager::slotInstallProgressFinished(bool bsuccess, int err)
 
         // 网络错误
         if (err == EC_NETWORK) {
+            qCWarning(appLog) << "Network error, failing all pending installations.";
             failAllIndex();
             failedNum += m_ListDriverIndex.size();
             m_ListDriverIndex.clear();
@@ -364,18 +404,24 @@ void PageDriverManager::slotInstallProgressFinished(bool bsuccess, int err)
     // 如果有其它驱动，则显示安装内容
     if (m_ListDriverIndex.size() > 0) {
         sleep(1);
+        qCDebug(appLog) << "More drivers to install, proceeding to next one.";
         installNextDriver();
     } else {
+        qCDebug(appLog) << "All installations finished.";
         // 设置头部显示效果
         if (successNum > 0) {
+            qCDebug(appLog) << "Setting install success UI.";
             mp_DriverInstallInfoPage->headWidget()->setInstallSuccessUI(QString::number(successNum), QString::number(failedNum));
         } else {
+            qCDebug(appLog) << "Setting install failed UI.";
             mp_DriverInstallInfoPage->headWidget()->setInstallFailedUI();
         }
 
         if (m_ListUpdateIndex.isEmpty()) {
+            qCDebug(appLog) << "No updatable drivers, disabling header checkbox.";
             mp_DriverInstallInfoPage->setHeaderCbEnable(false);
         } else {
+            qCDebug(appLog) << "Updatable drivers remaining, enabling header checkbox.";
             mp_DriverInstallInfoPage->setHeaderCbEnable(true);
         }
         mp_DriverInstallInfoPage->headWidget()->setReDetectEnable(true);
@@ -387,6 +433,7 @@ void PageDriverManager::slotInstallProgressFinished(bool bsuccess, int err)
         m_CancelIndex = -1;
         successNum = 0;
         failedNum = 0;
+        qCDebug(appLog) << "Resetting installation state variables.";
     }
 }
 
@@ -402,6 +449,7 @@ void PageDriverManager::slotInstallAllDrivers()
 
 void PageDriverManager::slotBackupAllDrivers()
 {
+    qCDebug(appLog) << "PageDriverManager::slotBackupAllDrivers";
     mp_DriverInstallInfoPage->headWidget()->setReDetectEnable(false);
     mp_DriverRestoreInfoPage->headWidget()->setReDetectEnable(false);
 
@@ -410,6 +458,7 @@ void PageDriverManager::slotBackupAllDrivers()
 
 void PageDriverManager::slotScanFinished(ScanResult sr)
 {
+    qCDebug(appLog) << "Driver scan finished, result:" << sr;
 //     testDevices();
 
     if (SR_SUCESS == sr) {
@@ -466,6 +515,7 @@ void PageDriverManager::slotScanFinished(ScanResult sr)
 
 void PageDriverManager::slotUndoInstall()
 {
+    qCDebug(appLog) << "PageDriverManager::slotUndoInstall";
     if (m_CancelIndex != m_CurIndex) {
         m_CancelIndex = m_CurIndex;
         DBusDriverInterface::getInstance()->undoInstallDriver();
@@ -479,6 +529,7 @@ void PageDriverManager::slotUndoInstall()
 
 void PageDriverManager::slotUndoBackup()
 {
+    qCDebug(appLog) << "PageDriverManager::slotUndoBackup";
     mp_BackupThread->undoBackup();
 
     // 直接清空列表，不再备份剩余的驱动
@@ -490,6 +541,7 @@ void PageDriverManager::slotUndoBackup()
 
 void PageDriverManager::slotListViewWidgetItemClicked(const QString &itemStr)
 {
+    qCDebug(appLog) << "PageDriverManager::slotListViewWidgetItemClicked, itemStr:" << itemStr;
     m_CurItemStr = itemStr;
     if (tr("Driver Install") == itemStr) {
         mp_StackWidget->setCurrentIndex(0);
@@ -502,27 +554,34 @@ void PageDriverManager::slotListViewWidgetItemClicked(const QString &itemStr)
 
 void PageDriverManager::slotBackupProgressChanged(int progress)
 {
+    qCDebug(appLog) << "PageDriverManager::slotBackupProgressChanged, progress:" << progress;
 
 }
 
 void PageDriverManager::slotBackupFinished(bool bsuccess)
 {
-    if (! mp_CurBackupDriverInfo)
+    qCDebug(appLog) << "PageDriverManager::slotBackupFinished, success:" << bsuccess;
+    if (! mp_CurBackupDriverInfo) {
+        qCWarning(appLog) << "Current backup driver info is null, returning.";
         return;
+    }
 
     if (bsuccess) {
         m_backupSuccessNum += 1;
+        qCDebug(appLog) << "Backup successful for" << mp_CurBackupDriverInfo->name() << ", success count:" << m_backupSuccessNum;
         // 备份成功, 直接添加到可还原列表,并在可备份列表中移除该项
         m_ListBackedupeIndex.append(m_CurBackupIndex);
         getDebBackupInfo(m_ListDriverInfo[m_CurBackupIndex]);
         if (m_ListDriverInfo[m_CurBackupIndex]->debBackupVersion() != m_ListDriverInfo[m_CurBackupIndex]->version()) {
             m_ListRestorableIndex.append(m_CurBackupIndex);
             mp_DriverRestoreInfoPage->addDriverInfoToTableView(m_ListDriverInfo[m_CurBackupIndex], m_CurBackupIndex);
+            qCDebug(appLog) << "Added" << m_ListDriverInfo[m_CurBackupIndex]->name() << "to restorable list.";
         }
         mp_DriverRestoreInfoPage->showTables(m_ListRestorableIndex.size());
         m_ListBackableIndex.removeAt(m_ListBackableIndex.indexOf(m_CurBackupIndex));
     } else {
         m_backupFailedNum += 1;
+        qCWarning(appLog) << "Backup failed for" << mp_CurBackupDriverInfo->name() << ", failed count:" << m_backupFailedNum;
     }
 
     // 安装结束后，对应的表格需要设置相应的状态
@@ -531,12 +590,16 @@ void PageDriverManager::slotBackupFinished(bool bsuccess)
 
     if (!m_ListBackupIndex.isEmpty()) {
         sleep(1);
+        qCDebug(appLog) << "More drivers to back up, proceeding to next one.";
         backupNextDriver();
     } else {
+        qCDebug(appLog) << "All backups finished.";
         if (!m_ListBackableIndex.isEmpty()) {
+            qCDebug(appLog) << "Setting backable driver UI.";
             mp_DriverBackupInfoPage->headWidget()->setBackableDriverUI(m_ListBackableIndex.size(), m_ListBackedupeIndex.size());
             mp_DriverBackupInfoPage->setHeaderCbEnable(true);
         } else {
+            qCDebug(appLog) << "Setting no backup driver UI.";
             mp_DriverBackupInfoPage->headWidget()->setNoBackupDriverUI(m_ListBackableIndex.size(), m_ListBackedupeIndex.size());
             mp_DriverBackupInfoPage->setHeaderCbEnable(false);
         }
@@ -549,32 +612,43 @@ void PageDriverManager::slotBackupFinished(bool bsuccess)
         m_CurBackupIndex = -1;
         m_backupSuccessNum = 0;
         m_backupFailedNum = 0;
+        qCDebug(appLog) << "Resetting backup state variables.";
     }
 }
 
 void PageDriverManager::slotRestoreProgress(int progress, QString strDeatils)
 {
-    if(mp_CurRestoreDriverInfo == nullptr)
+    qCDebug(appLog) << "PageDriverManager::slotRestoreProgress, progress:" << progress << "details:" << strDeatils;
+    if(mp_CurRestoreDriverInfo == nullptr) {
+        qCWarning(appLog) << "Current restore driver info is null, returning.";
         return;
+    }
     if (progress >= 100) {
+        qCDebug(appLog) << "Restore progress >= 100, setting restore driver UI.";
         mp_DriverRestoreInfoPage->headWidget()->setRestoreDriverUI(m_ListRestorableIndex.size());
     } else {
+        qCDebug(appLog) << "Restore progress < 100, setting restoring UI.";
         mp_DriverRestoreInfoPage->headWidget()->setRestoringUI(progress, mp_CurRestoreDriverInfo->name());
     }
 }
 
 void PageDriverManager::slotRestoreFinished(bool success, QString msg)
 {
+    qCDebug(appLog) << "PageDriverManager::slotRestoreFinished, success:" << success << "msg:" << msg;
     int index = -1;
     if (mp_CurRestoreDriverInfo) {
         index = m_ListDriverInfo.indexOf(mp_CurRestoreDriverInfo);
+        qCDebug(appLog) << "Restore finished for driver at index:" << index;
         for (int i = 0; i < m_ListRestorableIndex.size(); i++) {
             if (index == m_ListRestorableIndex[i]) {
+                qCDebug(appLog) << "Found restored driver in restorable list at index:" << i;
                 if (success) {
+                    qCDebug(appLog) << "Restore successful, removing from restorable list.";
                     //移除已还原项
                     m_ListRestorableIndex.removeAt(i);
                     mp_DriverRestoreInfoPage->headWidget()->setRestoreDriverUI(m_ListRestorableIndex.size());
                 } else {
+                    qCWarning(appLog) << "Restore failed, showing error dialog.";
                     //还原失败，弹出提示窗口
                     int clickedButtonIndex = mp_FailedDialog->exec();
                     if (1 == clickedButtonIndex) {
@@ -585,13 +659,18 @@ void PageDriverManager::slotRestoreFinished(bool success, QString msg)
                 }
 
                 //恢复其它置灰项
+                qCDebug(appLog) << "Re-enabling other restorable items.";
                 for (int backedupeIndex : m_ListRestorableIndex) {
-                    if (backedupeIndex != i)
+                    if (backedupeIndex != i) {
+                        // qCDebug(appLog) << "Enabling item at index:" << backedupeIndex;
                         mp_DriverRestoreInfoPage->setItemOperationEnable(backedupeIndex, true);
+                    }
                 }
                 break;
             }
         }
+    } else {
+        qCWarning(appLog) << "Current restore driver info is null.";
     }
 
     mp_DriverInstallInfoPage->headWidget()->setReDetectEnable(true);
@@ -599,9 +678,11 @@ void PageDriverManager::slotRestoreFinished(bool success, QString msg)
     mp_DriverRestoreInfoPage->headWidget()->setReDetectEnable(true);
 
     mp_CurRestoreDriverInfo = nullptr;
+    qCDebug(appLog) << "Resetting restore state variables.";
 
     //刷新表格内容
     mp_DriverRestoreInfoPage->clearAllData();
+    qCDebug(appLog) << "Refreshing restore page table view.";
     for (int backedupeIndex : m_ListRestorableIndex) {
         mp_DriverRestoreInfoPage->addDriverInfoToTableView(m_ListDriverInfo[backedupeIndex], backedupeIndex);
     }
@@ -610,6 +691,7 @@ void PageDriverManager::slotRestoreFinished(bool success, QString msg)
 
 void PageDriverManager::initWidget()
 {
+    qCDebug(appLog) << "PageDriverManager::initWidget start";
     QHBoxLayout *mainLayout = new QHBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(0);
@@ -636,19 +718,23 @@ void PageDriverManager::initWidget()
     mp_FailedDialog->addContent(contentFrame);
     mp_FailedDialog->addButton(tr("OK"), false, DDialog::ButtonNormal);
     mp_FailedDialog->addButton(tr("Feedback"), false, DDialog::ButtonNormal);
+    qCDebug(appLog) << "PageDriverManager::initWidget end";
 }
 
 void PageDriverManager::installNextDriver()
 {
+    qCDebug(appLog) << "PageDriverManager::installNextDriver start";
     if (!m_ListDriverIndex.isEmpty()) {
         m_CurIndex = m_ListDriverIndex[0];
         m_ListDriverIndex.removeAt(0);
         DriverInfo *info = m_ListDriverInfo[m_CurIndex];
+        qCDebug(appLog) << "Installing driver at index:" << m_CurIndex << "Name:" << info->name();
         if (info) {
             mp_CurDriverInfo = info;
             mp_CurDriverInfo->m_Status = ST_DOWNLOADING;
             mp_DriverInstallInfoPage->updateItemStatus(m_CurIndex, mp_CurDriverInfo->status());
             mp_DriverInstallInfoPage->headWidget()->setDownloadUI(mp_CurDriverInfo->type(), "0MB/s", "0MB", mp_CurDriverInfo->size(), 0);
+            qCDebug(appLog) << "Calling DBus to install driver:" << info->packages() << "version:" << info->debVersion();
             DBusDriverInterface::getInstance()->installDriver(info->packages(), info->debVersion());
         }
     }
@@ -656,10 +742,12 @@ void PageDriverManager::installNextDriver()
 
 void PageDriverManager::backupNextDriver()
 {
+    qCDebug(appLog) << "PageDriverManager::backupNextDriver start";
     if (!m_ListBackupIndex.isEmpty()) {
         m_CurBackupIndex = m_ListBackupIndex[0];
         m_ListBackupIndex.removeAt(0);
         DriverInfo *info = m_ListDriverInfo[m_CurBackupIndex];
+        qCDebug(appLog) << "Backing up driver at index:" << m_CurBackupIndex << "Name:" << info->name();
         if (info) {
             mp_CurBackupDriverInfo = info;
             qCDebug(appLog) << __func__ << "backup driver: " << mp_CurBackupDriverInfo->name();
@@ -669,6 +757,7 @@ void PageDriverManager::backupNextDriver()
                                                                         m_ListBackupIndex.size() + m_backupSuccessNum + m_backupFailedNum + 1,
                                                                         m_backupSuccessNum + m_backupFailedNum + 1);
             if (!mp_BackupThread->isRunning()) {
+                qCDebug(appLog) << "Backup thread is not running, starting it.";
                 mp_BackupThread->setBackupDriverInfo(info);
                 mp_BackupThread->start();
             }
@@ -678,6 +767,7 @@ void PageDriverManager::backupNextDriver()
 
 void PageDriverManager::scanDevices()
 {
+    qCDebug(appLog) << "PageDriverManager::scanDevices start";
     // 显卡
     scanDevicesInfo(QObject::tr("Display Adapter"), DR_Gpu);
 
@@ -697,10 +787,12 @@ void PageDriverManager::scanDevices()
 //    scanDevicesInfo(QObject::tr("Printer"), DR_Printer); //由于task 353401 要求
 
 //    scanDevicesInfo(QObject::tr("Other Devices"), DR_OtherDevice); //由于task 353401 要求
+    qCDebug(appLog) << "PageDriverManager::scanDevices end";
 }
 
 void PageDriverManager::testScanDevices()
 {
+    qCDebug(appLog) << "PageDriverManager::testScanDevices";
     DriverInfo *info = new DriverInfo();
     info->m_Name = "GeFore RTX30 Series (Notebooks) 001";
     info->m_Size = "124.36";
@@ -804,11 +896,14 @@ void PageDriverManager::testScanDevices()
 
 void PageDriverManager::scanDevicesInfo(const QString &deviceType, DriverType driverType)
 {
+    qCDebug(appLog) << "PageDriverManager::scanDevicesInfo, deviceType:" << deviceType << "driverType:" << driverType;
     // 显卡
     QList<DeviceBaseInfo *> lst;
     bool ret = DeviceManager::instance()->getDeviceList(deviceType, lst);
+    qCDebug(appLog) << "Getting device list for" << deviceType << ", result:" << ret << ", count:" << lst.size();
     if (ret) {
         foreach (DeviceBaseInfo *device, lst) {
+            qCDebug(appLog) << "Processing device:" << device->name();
             DriverInfo *info = new DriverInfo();
             info->m_Name = device->name();        // 设备名称
             info->m_Type = driverType;
@@ -827,6 +922,7 @@ void PageDriverManager::scanDevicesInfo(const QString &deviceType, DriverType dr
             if ((info->m_VendorId.isEmpty() || info->m_ModelId.isEmpty()) && vidAndPid.size() == 10 && vidAndPid.startsWith("0x")) {
                 info->m_VendorId = vidAndPid.mid(0,6);
                 info->m_ModelId = "0x" + vidAndPid.mid(6,4);
+                qCDebug(appLog) << "Extracted VID and PID:" << info->m_VendorId << info->m_ModelId;
             }
 
             qCInfo(appLog) << "m_Name" << info->m_Name;
@@ -839,12 +935,14 @@ void PageDriverManager::scanDevicesInfo(const QString &deviceType, DriverType dr
             if (print != nullptr) {
                 info->m_VendorName = device->vendor();           // vendor name
                 info->m_ModelName = print->makeAndeModel();      // model name
+                qCDebug(appLog) << "Device is a printer, vendor:" << info->m_VendorName << "model:" << info->m_ModelName;
             }
 
             DeviceNetwork *network = dynamic_cast<DeviceNetwork *>(device);
             if (network != nullptr) {
                 if (network->isWireless()) {
                     info->m_Type = DR_WiFi;
+                    qCDebug(appLog) << "Device is a wireless network adapter.";
                 }
             }
 
@@ -855,6 +953,7 @@ void PageDriverManager::scanDevicesInfo(const QString &deviceType, DriverType dr
 
 void PageDriverManager::clearAllData()
 {
+    qCDebug(appLog) << "PageDriverManager::clearAllData start";
     m_ListNewIndex.clear();
     m_ListDriverIndex.clear();
     m_ListUpdateIndex.clear();
@@ -865,17 +964,21 @@ void PageDriverManager::clearAllData()
     m_ListRestorableIndex.clear();
 
     foreach (DriverInfo *info, m_ListDriverInfo) {
+        // qCDebug(appLog) << "Deleting driver info:" << info->name();
         delete info;
+        // info = nullptr;
     }
     m_ListDriverInfo.clear();
 
     mp_DriverInstallInfoPage->clearAllData();
     mp_DriverBackupInfoPage->clearAllData();
     mp_DriverRestoreInfoPage->clearAllData();
+    qCDebug(appLog) << "PageDriverManager::clearAllData end";
 }
 
 void PageDriverManager::addToDriverIndex(int index)
 {
+    qCDebug(appLog) << "PageDriverManager::addToDriverIndex, index:" << index;
     // 如果第一次添加到index，一键安装按钮置灰
     if (m_ListDriverIndex.size() <= 0) {
         mp_DriverInstallInfoPage->headWidget()->setInstallBtnEnable(true);
@@ -884,31 +987,37 @@ void PageDriverManager::addToDriverIndex(int index)
     bool add = true;
     for (int i = 0; i < m_ListDriverIndex.size(); i++) {
         if (index == m_ListDriverIndex[i]) {
+            qCDebug(appLog) << "Index" << index << "already exists in driver index list.";
             add = false;
             break;
         }
     }
 
     if (add) {
+        qCDebug(appLog) << "Adding index" << index << "to driver index list.";
         m_ListDriverIndex.append(index);
     }
 }
 
 void PageDriverManager::addToBackupIndex(int index)
 {
+    qCDebug(appLog) << "PageDriverManager::addToBackupIndex, index:" << index;
     if (m_ListBackupIndex.isEmpty()) {
         mp_DriverBackupInfoPage->headWidget()->setBackupBtnEnable(true);
     }
 
     int ret = m_ListBackupIndex.indexOf(index);
+    qCDebug(appLog) << "Checking if index" << index << "exists in backup index list, result:" << ret;
 
     if (ret < 0) {
+        qCDebug(appLog) << "Adding index" << index << "to backup index list.";
         m_ListBackupIndex.append(index);
     }
 }
 
 void PageDriverManager::removeFromDriverIndex(int index)
 {
+    qCDebug(appLog) << "PageDriverManager::removeFromDriverIndex, index:" << index;
     auto ret = m_ListDriverIndex.indexOf(index);
     if (ret >= 0) {
         m_ListDriverIndex.removeAt(ret);
@@ -922,6 +1031,7 @@ void PageDriverManager::removeFromDriverIndex(int index)
 
 void PageDriverManager::removeFromBackupIndex(int index)
 {
+    qCDebug(appLog) << "PageDriverManager::removeFromBackupIndex, index:" << index;
     auto ret = m_ListBackupIndex.indexOf(index);
     if (ret >= 0) {
         m_ListBackupIndex.removeAt(ret);
@@ -934,6 +1044,7 @@ void PageDriverManager::removeFromBackupIndex(int index)
 
 void PageDriverManager::failAllIndex()
 {
+    qCDebug(appLog) << "PageDriverManager::failAllIndex";
     foreach (int index, m_ListDriverIndex) {
         QString errS = DApplication::translate("QObject", CommonTools::getErrorString(EC_NETWORK).toStdString().data());
         mp_DriverInstallInfoPage->updateItemStatus(index, ST_FAILED, errS);
@@ -942,16 +1053,22 @@ void PageDriverManager::failAllIndex()
 
 bool PageDriverManager::networkIsOnline()
 {
+    qCDebug(appLog) << "PageDriverManager::networkIsOnline start";
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QNetworkConfigurationManager mgr;
-    return mgr.isOnline();
+    const bool isOnline = mgr.isOnline();
+    qCDebug(appLog) << "Network is" << (isOnline ? "online" : "offline");
+    return isOnline;
 #else
-    return QNetworkInformation::instance() && QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Disconnected;
+    auto interfaces = QNetworkInformation::instance()->reachability();
+    qCDebug(appLog) << "Network reachability:" << interfaces;
+    return interfaces == QNetworkInformation::Reachability::Disconnected;
 #endif
 }
 
 void PageDriverManager::getDownloadInfo(int progress, qint64 total, QString &speed, QString &size)
 {
+    qCDebug(appLog) << "PageDriverManager::getDownloadInfo, progress:" << progress << "total:" << total;
     static qint64 msec = QDateTime::currentMSecsSinceEpoch();
     static double pre_bytes = total * (progress / 100.0);
     double bytes = total * (progress / 100.0);
@@ -989,6 +1106,7 @@ void PageDriverManager::getDownloadInfo(int progress, qint64 total, QString &spe
 
 void PageDriverManager::testDevices()
 {
+    qCDebug(appLog) << "PageDriverManager::testDevices";
     DriverInfo *info = new DriverInfo();
     info->m_Name = "Sharp MX-C2622R PS, 1.1";
     info->m_Version = "0.0.1";
@@ -1028,16 +1146,21 @@ void PageDriverManager::testDevices()
 
 void PageDriverManager::getDebBackupInfo(DriverInfo *info)
 {
+    qCDebug(appLog) << "PageDriverManager::getDebBackupInfo, debname:" << info->packages();
     QString debname = info->packages();
     QString backupPath =  QString("%1/driver/%2").arg(CommonTools::getBackupPath()).arg(debname);
     QDir destdir(backupPath);
+    qCDebug(appLog) << "Checking for backup in path:" << backupPath;
     if (destdir.exists()) {
+        qCDebug(appLog) << "Backup path exists, searching for .deb file.";
         //获取当前路径下的所有文件名
         QFileInfoList fileInfoList = destdir.entryInfoList();
         foreach (QFileInfo fileInfo, fileInfoList) {
             if (fileInfo.fileName() == "." || fileInfo.fileName() == "..")
                 continue;
+            qCDebug(appLog) << "Checking file:" << fileInfo.fileName();
             if (fileInfo.isFile() && fileInfo.fileName().contains(".deb") && fileInfo.fileName().contains(debname)) {
+                qCDebug(appLog) << "Found backup .deb file:" << fileInfo.fileName();
                 QString tmps = fileInfo.fileName().remove(debname).remove(".deb");
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 QStringList  tmpsl = tmps.split('_', QString::SkipEmptyParts);
