@@ -3,6 +3,8 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "DBusWakeupInterface.h"
+#include "DDLog.h"
+#include <DSysInfo>
 
 #include <QDBusConnection>
 #include <QDBusInterface>
@@ -11,6 +13,8 @@
 #include <QFile>
 #include <QMetaMethod>
 
+using namespace DDLog;
+
 // 以下这个问题可以避免单例的内存泄露问题
 std::atomic<DBusWakeupInterface *> DBusWakeupInterface::s_Instance;
 std::mutex DBusWakeupInterface::m_mutex;
@@ -18,25 +22,33 @@ std::mutex DBusWakeupInterface::m_mutex;
 const QString SERVICE_NAME = "org.deepin.DeviceControl";
 const QString WAKEUP_SERVICE_PATH = "/org/deepin/DeviceControl";
 const QString WAKEUP_INTERFACE = "org.deepin.DeviceControl";
-#ifdef OS_BUILD_V23
-const QString INPUT_SERVICE_NAME = "org.deepin.dde.InputDevices1";
-const QString INPUT_WAKEUP_SERVICE_PATH = "/org/deepin/dde/InputDevices1";
-const QString INPUT_WAKEUP_INTERFACE = "org.deepin.dde.InputDevices1";
-#else
-const QString INPUT_SERVICE_NAME = "com.deepin.system.InputDevices";
-const QString INPUT_WAKEUP_SERVICE_PATH = "/com/deepin/system/InputDevices";
-const QString INPUT_WAKEUP_INTERFACE = "com.deepin.system.InputDevices";
-#endif
+
+const QString INPUT_SERVICE_NAME_V23 = "org.deepin.dde.InputDevices1";
+const QString INPUT_WAKEUP_SERVICE_PATH_V23 = "/org/deepin/dde/InputDevices1";
+const QString INPUT_WAKEUP_INTERFACE_V23 = "org.deepin.dde.InputDevices1";
+
+const QString INPUT_SERVICE_NAME_V20 = "com.deepin.system.InputDevices";
+const QString INPUT_WAKEUP_SERVICE_PATH_V20 = "/com/deepin/system/InputDevices";
+const QString INPUT_WAKEUP_INTERFACE_V20 = "com.deepin.system.InputDevices";
+
+inline bool isV20() { return Dtk::Core::DSysInfo::majorVersion() == "20"; }
+const QString INPUT_SERVICE_NAME = isV20() ? INPUT_SERVICE_NAME_V20 : INPUT_SERVICE_NAME_V23;
+const QString INPUT_WAKEUP_SERVICE_PATH = isV20() ? INPUT_WAKEUP_SERVICE_PATH_V20 : INPUT_WAKEUP_SERVICE_PATH_V23;
+const QString INPUT_WAKEUP_INTERFACE = isV20() ? INPUT_WAKEUP_INTERFACE_V20 : INPUT_WAKEUP_INTERFACE_V23;
+
 const QString INPUT_WAKEUP_PROPERTIES_INTERFACE = "org.freedesktop.DBus.Properties";
 
 DBusWakeupInterface::DBusWakeupInterface()
     : mp_Iface(nullptr), mp_InputIface(nullptr)
 {
+    qCDebug(appLog) << "DBusWakeupInterface constructor called";
     init();
 }
 
 bool DBusWakeupInterface::setWakeupMachine(const QString &unique_id, const QString &path, bool wakeup, const QString &name)
 {
+    qCDebug(appLog) << "Setting wakeup for device. ID:" << unique_id << "Path:" << path << "Wakeup:" << wakeup << "Name:" << name;
+
     if (nullptr != mp_InputIface && mp_InputIface->isValid()) {
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QStringList pathList = path.split("/", QString::SkipEmptyParts);
@@ -46,6 +58,7 @@ bool DBusWakeupInterface::setWakeupMachine(const QString &unique_id, const QStri
         if (pathList.size() < 3)
             return false;
 
+        qCDebug(appLog) << "Processing PS/2 device";
         if (name.contains("PS/2")) {
             // ps2设备无法通过/sys/devices/platform/i8042/serio1/power/wakeup控制，只能通过acpi的接口进行控制
             QDBusInterface interface(INPUT_SERVICE_NAME, INPUT_WAKEUP_SERVICE_PATH, INPUT_WAKEUP_PROPERTIES_INTERFACE, QDBusConnection::systemBus());
@@ -67,6 +80,7 @@ bool DBusWakeupInterface::setWakeupMachine(const QString &unique_id, const QStri
                 }
             }
         } else {
+            qCDebug(appLog) << "Processing non-PS/2 device";
             auto metaObject = mp_InputIface->metaObject();
             for (int i = 0 ; i < metaObject->methodCount(); ++i) {
                 if (metaObject->method(i).name() == "SetWakeupDevices") {
@@ -79,6 +93,7 @@ bool DBusWakeupInterface::setWakeupMachine(const QString &unique_id, const QStri
         }
     }
 
+    qCDebug(appLog) << "Calling DBus setWakeupMachine";
     QDBusReply<bool> reply = mp_Iface->call("setWakeupMachine", unique_id, path, wakeup);
     if (reply.isValid()) {
         return reply.value();
@@ -88,7 +103,11 @@ bool DBusWakeupInterface::setWakeupMachine(const QString &unique_id, const QStri
 
 bool DBusWakeupInterface::canInputWakeupMachine(const QString &path)
 {
-    if (nullptr != mp_InputIface && mp_InputIface->isValid()) {
+    qCDebug(appLog) << "Checking if input device can wakeup machine. Path:" << path;
+
+    bool inputIfaceValid = (nullptr != mp_InputIface && mp_InputIface->isValid());
+    qCDebug(appLog) << "Input interface valid:" << inputIfaceValid;
+    if (inputIfaceValid) {
         QDBusInterface interface(INPUT_SERVICE_NAME, INPUT_WAKEUP_SERVICE_PATH, INPUT_WAKEUP_PROPERTIES_INTERFACE, QDBusConnection::systemBus());
         if (interface.isValid()) {
             QDBusMessage replay = interface.call("Get", INPUT_WAKEUP_INTERFACE, "SupportWakeupDevices");
@@ -110,13 +129,18 @@ bool DBusWakeupInterface::canInputWakeupMachine(const QString &path)
         }
     }
 
+    qCDebug(appLog) << "Falling back to file check for wakeup capability";
     QFile file(path);
     return file.open(QIODevice::ReadOnly);
 }
 
 bool DBusWakeupInterface::isInputWakeupMachine(const QString &path, const QString &name)
 {
-    if (nullptr != mp_InputIface && mp_InputIface->isValid()) {
+    qCDebug(appLog) << "Checking input wakeup state. Path:" << path << "Name:" << name;
+
+    bool inputIfaceValid = (nullptr != mp_InputIface && mp_InputIface->isValid());
+    qCDebug(appLog) << "Input interface valid:" << inputIfaceValid;
+    if (inputIfaceValid) {
         QDBusInterface interface(INPUT_SERVICE_NAME, INPUT_WAKEUP_SERVICE_PATH, INPUT_WAKEUP_PROPERTIES_INTERFACE, QDBusConnection::systemBus());
         if (interface.isValid()) {
             QDBusMessage replay = interface.call("Get", INPUT_WAKEUP_INTERFACE, "SupportWakeupDevices");
@@ -164,6 +188,7 @@ int DBusWakeupInterface::isNetworkWakeup(const QString &logical_name)
 
 bool DBusWakeupInterface::setNetworkWakeup(const QString &logical_name, bool wake)
 {
+    qCDebug(appLog) << "Calling DBus setNetworkWake";
     QDBusReply<bool> reply = mp_Iface->call("setNetworkWake", logical_name, wake);
     if (reply.isValid()) {
         return reply.value();
@@ -174,8 +199,12 @@ bool DBusWakeupInterface::setNetworkWakeup(const QString &logical_name, bool wak
 
 void DBusWakeupInterface::init()
 {
+    qCDebug(appLog) << "Initializing DBus interfaces";
+
     // 1. 连接到dbus
-    if (!QDBusConnection::systemBus().isConnected()) {
+    bool isConnected = QDBusConnection::systemBus().isConnected();
+    qCDebug(appLog) << "DBus system bus connected:" << isConnected;
+    if (!isConnected) {
         fprintf(stderr, "Cannot connect to the D-Bus session bus./n"
                 "To start it, run:/n"
                 "/teval `dbus-launch --auto-syntax`/n");
